@@ -47,8 +47,6 @@ class CodeStyleChecker:
             prev_token = self.get_prev_token(tokens, i)
             next_token = self.get_next_token(tokens, i)
             next_next_token = self.get_next_token(tokens, i + 1)
-            if cur_token.value == "<" and next_token is not None and next_token.value == "HTTP":
-                print("HTTP")
             if cur_token.token_name == TokenName.IDENTIFIER:
                 if i + 1 < len(tokens) and tokens[i + 1].value == "::":  # namespace or type names before ::
                     if cur_token.value in self.defined_namespaces:
@@ -133,8 +131,11 @@ class CodeStyleChecker:
                     cur_output = format_const_var_name(cur_token.value)
                     self.log_if_need(file_path, cur_token, cur_output, ErrorType.EnumMemberNameError, working_mode)
                 elif len(token_stack) > 0 and token_stack[-1] == "namespace":
-                    cur_output = format_common_var_name(cur_token.value)
-                    self.log_if_need(file_path, cur_token, cur_output, ErrorType.NamespaceNameError, working_mode)
+                    if cur_token.value in self.defined_namespaces:
+                        cur_output = format_common_var_name(cur_token.value)
+                        self.log_if_need(file_path, cur_token, cur_output, ErrorType.NamespaceNameError, working_mode)
+                    else:
+                        cur_output = cur_token.value
                 elif prev_token is not None and prev_token.value in ('.', '->'):
                     if cur_token.value in self.defined_class_members:
                         cur_output = format_class_var_name(cur_token.value)
